@@ -33,19 +33,11 @@ import string
 import binascii
 from pprint import pformat
 from subprocess import Popen, PIPE
+from unittest import mock
 
 from awscli.compat import StringIO
 
 
-try:
-    import mock
-except ImportError as e:
-    # In the off chance something imports this module
-    # that's not suppose to, we should not stop the CLI
-    # by raising an ImportError.  Now if anything actually
-    # *uses* this module that isn't suppose to, that's a
-    # different story.
-    mock = None
 from awscli.compat import six
 from botocore.session import Session
 from botocore.exceptions import ClientError
@@ -59,13 +51,7 @@ from awscli.clidriver import CLIDriver
 from awscli import EnvironmentVariables
 
 
-# The unittest module got a significant overhaul
-# in 2.7, so if we're in 2.6 we can use the backported
-# version unittest2.
-if sys.version_info[:2] == (2, 6):
-    import unittest2 as unittest
-else:
-    import unittest
+import unittest
 
 
 # In python 3, order matters when calling assertEqual to
@@ -97,18 +83,6 @@ def skip_if_windows(reason):
     return decorator
 
 
-def set_invalid_utime(path):
-    """Helper function to set an invalid last modified time"""
-    try:
-        os.utime(path, (-1, -100000000000))
-    except (OSError, OverflowError):
-        # Some OS's such as Windows throws an error for trying to set a
-        # last modified time of that size. So if an error is thrown, set it
-        # to just a negative time which will trigger the warning as well for
-        # Windows.
-        os.utime(path, (-1, -1))
-
-
 def create_clidriver():
     driver = awscli.clidriver.create_clidriver()
     session = driver.session
